datadog\_api\_client.v1
=======================

.. toctree::
   :maxdepth: 4

   datadog_api_client.v1.api
   datadog_api_client.v1.model


.. automodule:: datadog_api_client.v1
   :members:
   :show-inheritance:
